@@ -66,7 +66,7 @@ class DataReader(ParameterizedClass, ABC):
     ---------------------------------------------------------------------------------"""
 
     @abstractmethod
-    def read(self, input_key: str) -> Union[xr.Dataset, Dict[str, xr.Dataset]]:
+    def read(self, input_key: str,) -> Union[xr.Dataset, Dict[str, xr.Dataset]]:
         """-----------------------------------------------------------------------------
         Reads data given an input key.
 
@@ -91,6 +91,26 @@ class DataReader(ParameterizedClass, ABC):
         ...
 
 
+class ArchiveReader(DataReader):
+    """------------------------------------------------------------------------------------
+    Base class for DataReader objects that read data from archives.
+    Subclasses of `ArchiveHandler` may define additional parameters to support various
+    methods of unpacking archived data.
+
+    ------------------------------------------------------------------------------------"""
+
+    exclude: str = ""
+
+    def __init__(self, parameters: Dict = None):  # type: ignore
+        super().__init__(parameters=parameters)
+
+        # Naively merge a list of regex patterns to exclude certain files from being
+        # read. By default we exclude files that macOS creates when zipping a folder.
+        exclude = [".*\\_\\_MACOSX/.*", ".*\\.DS_Store"]
+        exclude.extend(getattr(self.parameters, "exclude", []))
+        self.parameters.exclude = "(?:% s)" % "|".join(exclude)
+
+
 class DataWriter(ParameterizedClass, ABC):
     """---------------------------------------------------------------------------------
     Base class for writing data to storage area(s).
